@@ -71,6 +71,7 @@ function(y1, y2, m1, s11, method="plsr", p=1.0, ncomp.max=Inf, validation="CV",
     ## s22 <- reg$S + t(b1) %*% s11 %*% b1
     s22 <- reg$S + s21 %*% b1
 
+    ## perhaps print new components as we go along
     if(verb >= 2) {
       cat("\nnew components of mu: "); cat(paste(round(m2,2))); cat("\n")
       cat("\nnew cols of S:\n")
@@ -80,6 +81,6 @@ function(y1, y2, m1, s11, method="plsr", p=1.0, ncomp.max=Inf, validation="CV",
     
     ## return
     return(list(method=rep(reg$method, ncol(reg$b)), ncomp=reg$ncomp,
-                mu=m2, s21=s21, s22=s22))
+                lambda=reg$lambda, mu=m2, s21=s21, s22=s22))
   }
 
